summaryrefslogtreecommitdiffstats
path: root/importxml.pl
diff options
context:
space:
mode:
authorlpsolit%gmail.com <>2006-06-02 19:50:15 +0200
committerlpsolit%gmail.com <>2006-06-02 19:50:15 +0200
commit2b9f5bf80911872ca809061bd46d8fc7f64c2929 (patch)
tree29443975af530533739b1d7c442e8ebed5254430 /importxml.pl
parent24a02ebf00c318c3406fc4c4f38a8f93480b0548 (diff)
downloadbugzilla-2b9f5bf80911872ca809061bd46d8fc7f64c2929.tar.gz
bugzilla-2b9f5bf80911872ca809061bd46d8fc7f64c2929.tar.xz
Bug 339862: Move Bugzilla::BugMail::MessageToMTA() in a separate module - Patch by Frédéric Buclin <LpSolit@gmail.com> r=mkanat a=justdave
Diffstat (limited to 'importxml.pl')
-rwxr-xr-ximportxml.pl5
1 files changed, 3 insertions, 2 deletions
diff --git a/importxml.pl b/importxml.pl
index 08be03e5a..c1cdc56b6 100755
--- a/importxml.pl
+++ b/importxml.pl
@@ -81,6 +81,7 @@ use Bugzilla::Milestone;
use Bugzilla::FlagType;
use Bugzilla::Config qw(:DEFAULT $datadir);
use Bugzilla::BugMail;
+use Bugzilla::Mailer;
use Bugzilla::User;
use Bugzilla::Util;
use Bugzilla::Constants;
@@ -153,7 +154,7 @@ sub MailMessage {
$header .= "From: Bugzilla <$from>\n";
$header .= "Subject: $subject\n\n";
my $sendmessage = $header . $message . "\n";
- Bugzilla::BugMail::MessageToMTA($sendmessage);
+ MessageToMTA($sendmessage);
}
}
@@ -1198,7 +1199,7 @@ Debug( "Reading xml", DEBUG_LEVEL );
local ($/);
$xml = <>;
# If the email was encoded (BugMail::MessageToMTA() does it when using UTF-8),
# we have to decode it first, else the XML parsing will fail.
my $parser = MIME::Parser->new;
$parser->output_to_core(1);
@@ -1198,7 +1199,7 @@ Debug( "Reading xml", DEBUG_LEVEL );
local ($/);
$xml = <>;
-# If the email was encoded (BugMail::MessageToMTA() does it when using UTF-8),
+# If the email was encoded (Mailer::MessageToMTA() does it when using UTF-8),
# we have to decode it first, else the XML parsing will fail.
my $parser = MIME::Parser->new;